@@ -30,7 +30,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <unistd.h>
 #include <stdlib.h>
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <syslog.h>
@@ -45,9 +44,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 void init_logger();
 void init_threads(unsigned int count);
 void quit();
+void print_queue_status();
 void setBasedir(char *bd);
 void *t_shape(void *nulla);
-void setAuthbin(char *bin);
+void set_authsocket(char *);
 void chn_thread_count(int val);
 void set_new_uid(int uid);
 
