@@ -16,8 +16,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 @author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
-
- */
+*/
 
 #ifndef WEBORF_UTILS_H
 #define WEBORF_UTILS_H
@@ -30,14 +29,30 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <arpa/inet.h>
+#include <sys/stat.h>
+#include <dirent.h>
+#include <unistd.h>
+
+
 #include "mystring.h"
+#include "options.h"
+#include "types.h"
 
 bool file_exists(char *file);
-int list_dir(char *dir, char *html, unsigned int bufsize, bool parent);
+int list_dir(connection_t *connection_prop, char *html, unsigned int bufsize, bool parent);
 void help();
 void version();
 void moo();
 void setEnvVars(char *http_param);
 bool get_param_value(char *http_param, char *parameter, char *buf, ssize_t size,ssize_t param_len);
+int deep_rmdir(char * dir);
+
+#ifdef WEBDAV
+int dir_move_copy (char* source, char* dest,int method);
+int file_copy(char* source, char* dest);
+int file_move(char* source, char* dest);
+int dir_move (char* source, char* dest);
+int dir_copy (char* source, char* dest);
+#endif
 
 #endif
